/*
 *
 * This file is a part of the CaosDB Project.
 *
 * Copyright (C) 2021 Timm Fitschen <t.fitschen@indiscale.com>
 * Copyright (C) 2021 IndiScale GmbH <info@indiscale.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#include <memory>                  // for allocator, make_shared, unique_ptr
#include "caosdb/connection.h"     // for InsecureCaosDBConnectionConfig
#include "caosdb/entity.h"         // for EntityID
#include "caosdb/exceptions.h"     // for ConnectionError
#include "caosdb/transaction.h"    // for Transaction, EntityID
#include "gtest/gtest-message.h"   // for Message
#include "gtest/gtest-test-part.h" // for TestPartResult
#include "gtest/gtest.h"           // for Test, SuiteApiResolver, TestInfo ...
#include "caosdb_test_utility.h"   // for EXPECT_THROW_MESSAGE

namespace caosdb::transaction {
using caosdb::connection::CaosDBConnection;
using caosdb::connection::InsecureCaosDBConnectionConfig;
using caosdb::exceptions::ConnectionError;

TEST(test_transaction, create_transaction) {
  const auto *pHost = "localhost";
  auto config = std::make_shared<InsecureCaosDBConnectionConfig>(pHost, 8000);
  CaosDBConnection connection(config);
  auto transaction = connection.CreateTransaction();

  transaction->Retrieve(EntityID("someid"));
  EXPECT_THROW_MESSAGE(transaction->Execute(), ConnectionError,
                       "failed to connect to all addresses");
}

} // namespace caosdb::transaction
